## ----source,size="small"----------------------------------------------------------------
files <- list.files("funs/")
for(i in 1:length(files)){source(paste0("funs/",files[i]))}


## ----ar2pars,size="small"---------------------------------------------------------------
phi1 <- 1.25; phi2 <- -0.5
sigma <- 1


## ----simulate1,size="small"-------------------------------------------------------------
## Simulate
set.seed(1234)
T <- 1e6
n.burnin <- 1e4
y <- arima.sim(n = 2 * T + n.burnin, list(ar = c(phi1, phi2)), 
               sd = sigma)

## remove burnin
y <- y[-(1:n.burnin)]

## set up matrix
y1 <- y[seq(1,2 * T,by=2)]
y2 <- y[seq(2,2 * T,by=2)]
yA <- y1 + y2 ## anual process 
Y.train <- cbind(yA, y1, y2)


## ----estimateAR1Pars--------------------------------------------------------------------
## Estimate parameters in AR(1) models
phiH.hat <- coef(arima(y, order=c(1, 0, 0), include.mean=FALSE))
phiA.hat <- coef(arima(yA, order=c(1, 0, 0), include.mean=FALSE))


## ----autocorr,size="small"--------------------------------------------------------------
## Empirical results 
rho.hat <- acf(y, plot = FALSE)$acf[2:4]

## From article
rho.true <- rho.true.fun(phi1,phi2)

## Compare with estimated 
cbind(rho.hat, rho.true)


## ----autocov,size="small"---------------------------------------------------------------
## Empirical result
gamma.hat <- c(1,rho.hat) * var(y)

## From article
gamma.true <- gamma.true.fun(phi1,phi2,sigma)
cbind(gamma.hat,gamma.true)


## ----corAnual,size="small"--------------------------------------------------------------
rho1A.hat <- acf(yA,plot=FALSE)$acf[2]
rho1A.true <- (gamma.true[2] + 2 * gamma.true[3] + gamma.true[4]) / 
    (2 * (gamma.true[1]+gamma.true[2]))
c(rho1A.hat,rho1A.true)


## ----InSampleVarSim,size="small"--------------------------------------------------------
## calculations based on simulated process values
Y.hat <- Y.train * NA
Y.hat[-1, ] <- cbind(phiA.hat * yA[-T], phiH.hat * y2[-T],
                     phiH.hat^2 * y2[-T])
Sigma.hat <- var(Y.train[-1, ]- Y.hat[-1, ])


## ----InSampleVar,size="small"-----------------------------------------------------------
## True value of matrices (in eq. (A.4))
Gamma <- Gamma.fun(rho.true.fun(phi1, phi2)[1], rho1A.true)
Phi <- Phi.fun(phi1, phi2)
Phi.epsilon <- Phi.epsilon.fun(phi1, phi2)

## eq (A.7)
VyH <- matrix(gamma.true[2], ncol = 2, nrow = 2)
diag(VyH) <- gamma.true[1]

## eq (A.6)
Sigma.true <- (Phi - Gamma) %*% VyH %*% t(Phi - Gamma) + 
    sigma^2 * Phi.epsilon %*% t(Phi.epsilon)

## Compare
Sigma.hat - Sigma.true


## ----projection,size="small"------------------------------------------------------------
## Projection matrix
S <- matrix(0,ncol=2, nrow=3)
S[1, ] <- 1
S[2:3,1:2] <- diag(2)
Pfull.true <- solve(t(S) %*% solve(Sigma.true) %*% S) %*% 
    t(S) %*% solve(Sigma.true)
Pfull.hat <- solve(t(S) %*% solve(Sigma.hat) %*% S) %*% 
    t(S) %*% solve(Sigma.hat)

## trace
sum(diag(diag(3)-S%*%Pfull.true))
sum(diag(diag(3)-S%*%Pfull.hat))


## ----obsVar,size="small"----------------------------------------------------------------
H <- S %*% Pfull.hat
Y.tilde <- cbind(Y.hat %*% H[1,], Y.hat %*% H[2,], Y.hat %*% H[3,])

Sigma.tilde.sim <- var(Y.train[-1, ] - Y.tilde[-1, ])


## ----eqsA8,size="small"-----------------------------------------------------------------
Sigma.tilde <- (Phi - S %*% Pfull.true %*% Gamma) %*% VyH %*% 
      t(Phi - S %*% Pfull.true %*% Gamma) + 
      sigma^2 * Phi.epsilon %*% t(Phi.epsilon)

Sigma.tilde - Sigma.tilde.sim


## ----simTest,size="small"---------------------------------------------------------------
##################################################
## Generating a test set
## Simulate
set.seed(1234)
T.test <- 1e6
n.burnin <- 1e4
y.test <- arima.sim(n = 2 * T.test + n.burnin,
                    list(ar = c(phi1, phi2)),
                    sd = sigma)

y.test <- y.test[-(1:n.burnin)]

## set up matrix
y1 <- y.test[seq(1,2 * T.test,by=2)]
y2 <- y.test[seq(2,2 * T.test,by=2)]
yA <- y1 + y2
Y.test <- cbind(yA, y1, y2)


## ----AR1pred,size="small"---------------------------------------------------------------
Y.hat <- Y.test * NA
Y.hat[-1, ] <- cbind(phiA.hat * yA[-T.test], phiH.hat * y2[-T.test],
                     phiH.hat^2 * y2[-T.test])


## ----eqA6,size="small"------------------------------------------------------------------
Sigma.hat <- var(Y.test[-1, ]- Y.hat[-1, ])
Sigma.hat - Sigma.true


## ----EqA8sim,size="small"---------------------------------------------------------------
Y.tilde <- cbind(Y.hat %*% H[1, ], Y.hat %*% H[2, ], Y.hat %*% H[3, ])
Sigma.tilde.hat <- var(Y.tilde[-1, ] - Y.test[-1, ])
Sigma.tilde - Sigma.tilde.hat


## ----VarsFun,size="small"---------------------------------------------------------------
Vars <- VarFunTrue(phi1=1.5, phi2=-0.6, sigma = 1)
rbind(names(Vars)[1:3],names(Vars)[4:6])


## ----keynumTrue,size="small"------------------------------------------------------------
phi1 <- 0.75
phi2 <- seq(-0.75, 0.24, by = 0.01)
Summ <- VarFunRap(phi1, phi2)


## ----Fig1,fig.height=3,size="small",fig.cap="Reproducing the results in Figure 1 in the article"----
ylim = c(-12.5, 2.5)
plotFig1(Summ)


## ----PlotP,size="small",fig.cap="Elements of {\\tt Pfull} (top row) and {\\tt Pre} (bottom row). Black: $\\boldsymbol{P}_{i,1}$, red: $\\boldsymbol{P}_{i,2}$, green: $\\boldsymbol{P}_{i,3}$.",fig.height=5----
ylim = c(-0.6, 1.2)
plotProj(Summ)


## ----SimFuns,cache=TRUE,size="small"----------------------------------------------------
set.seed(1234)
phi1 <- 0.75
phi2 <- -0.2
T.train <- 1e3
T.test <- 1e3
sums.sim <- VarFunSim(phi1, phi2, T.train, T.test, n.burnin = 1e4, 
                      sigma = 1)


## ----SimFuns2,cache=TRUE,size="small"---------------------------------------------------
set.seed(1234)
k <- 1e3
sums.sim <- VarFunSim.k(phi1, phi2, T.train, T.test, k, 
                        n.burnin=1e4, sigma=1)


## ----SimRap1,cache=TRUE,size="small"----------------------------------------------------
set.seed(1234)
phi1 <- 0.75
phi2 <- seq(-0.75,0.24,by=0.01)
q <- c(0.05, 0.5, 0.95)

## Small training set
T.train <- 1e2
T.test <- 1e3
k <- 1e3
Summ.sim1 <- VarFunSimRap.k(phi1, phi2, T.train, T.test, k, q, 
                           n.burnin = 1e4, sigma = 1)

## Large training set
T.train <- 1e4
T.test <- 1e4
k <- 100
Summ.sim2 <- VarFunSimRap.k(phi1, phi2, T.train, T.test, k, q, 
                           n.burnin = 1e4, sigma = 1)


## ----PlotSim1,size="small",fig.cap="Comparing simulated and theoretical results using a small training set (top row) and a large training set (bottom row). Colors are as in the article, dotted lines represent 0.05 and 0.95 quantiles from simulations, and dashed line represent the median of the simulated values.",fig.height=6----
par(mfrow=c(2,3))
PlotSimRSd(Summ,Summ.sim1,q,lwd=2)
PlotSimRSd(Summ,Summ.sim2,q,lwd=2)


## ----PlotSimP1,size="small",fig.cap=" Elements of {\\tt Pfull} (top row) and {\\tt Pre} (bottom row), for the small training sets. Black: $\\boldsymbol{P}_{i,1}$, red: $\\boldsymbol{P}_{i,2}$, green: $\\boldsymbol{P}_{i,3}$. dotted lines represent 0.05 and 0.95 quantiles from simulations, and dashed line represent the median of the simulated values.",fig.height=5----
par(mfrow=c(2,2))
PlotSimP(Summ,Summ.sim1,q,lwd=2)


## ----PlotSimP2,size="small",fig.cap="Elements of {\\tt Pfull} (top row) and {\\tt Pre} (bottom row), for the large training sets. Black: $\\boldsymbol{P}_{i,1}$, red: $\\boldsymbol{P}_{i,2}$, green: $\\boldsymbol{P}_{i,3}$. dotted lines represent 0.05 and 0.95 quantiles from simulations, and dashed line represent the median of the simulated values.",fig.height=5----
par(mfrow=c(2,2))
PlotSimP(Summ,Summ.sim2,q,lwd=2)

