VarFunSim <- function(phi1,phi2,T.train,T.test,n.burnin=1e4,sigma=1){
    y.train <- arima.sim(n = 2 * T.train + n.burnin, list(ar = c(phi1, phi2)), sd = sigma)
    y.train <- y.train[-(1:n.burnin)]
    ## set up matrix
    y1.train <- y.train[seq(1, 2 * T.train,by=2)]
    y2.train <- y.train[seq(2, 2 * T.train,by=2)]
    yA.train <- y1.train + y2.train
    Y.train <- cbind(yA.train, y1.train, y2.train)
    phi1.hat <- coef(arima(y.train,order = c(1,0,0),include.mean=FALSE,method="CSS"))
    phi1A.hat <- coef(arima(yA.train,order = c(1,0,0),include.mean=FALSE,method="CSS"))
    
    Y.hat <- cbind(phi1A.hat * yA.train[-T.train], phi1.hat * y2.train[-T.train],
                   phi1.hat^2 * y2.train[-T.train])
    Sigma <- var(Y.train[-1, ]-Y.hat)

    Sigma.re <- Sigma
    Sigma.re[1,-1] <- Sigma.re[-1,1] <- 0
    
    ## Projection matrices
    Pfull <- solve(t(S) %*% solve(Sigma) %*% S) %*% 
        t(S) %*% solve(Sigma)
    Pre <- solve(t(S) %*% solve(Sigma.re) %*% S) %*% 
        t(S) %*% solve(Sigma.re)

    
    ## perfect model
    fit <- arima(y.train,order=c(2,0,0),include.mean = FALSE,method="CSS")
    phi1.perf <- coef(fit)[1]
    phi2.perf <- coef(fit)[2]
    
    ##################################################
    ## Test set
    ##################################################
    
    ## simulate
    y.test <- arima.sim(n = 2 * T.test + n.burnin, list(ar = c(phi1, phi2)), sd = sigma)
    y.test <- y.test[-(1:n.burnin)]
    ## set up matrix
    y1.test <- y.test[seq(1,2 * T.test, by=2)]
    y2.test <- y.test[seq(2,2 * T.test, by=2)]
    yA.test <- y1.test + y2.test
    Y.test <- cbind(yA.test, y1.test, y2.test)

    Y.hat <- cbind(phi1A.hat * yA.test[-T.test], phi1.hat * y2.test[-T.test],
                   phi1.hat^2 * y2.test[-T.test])
    y1.hat.perf <- phi1.perf * y2.test[-T.test] + phi2.perf * y1.test[-T.test]
    y2.hat.perf <- phi1.perf * y1.hat.perf[-T.test] + phi2.perf * y2.test[-T.test]
    
    Y.hat.perf <- cbind(y1.hat.perf + y2.hat.perf, y1.hat.perf, y2.hat.perf)
                        
                        
    ## Observed variances       
    Sigma <- var(Y.test[-1, ]-Y.hat)
    Sigma.perf <- var(Y.test[-1, ]-Y.hat.perf)

    ## Reconciled
    
    Hfull <- S %*% Pfull
    Hre <- S %*% Pre
    Y.tilde1 <- cbind(Y.hat%*%Hfull[1,],Y.hat%*%Hfull[2,],Y.hat%*%Hfull[3,])
    Y.tilde2 <- cbind(Y.hat%*%Hre[1,],Y.hat%*%Hre[2,],Y.hat%*%Hre[3,])

    
    Sigma.tilde <- var(Y.test[-1, ]-Y.tilde1)
    Sigma.tilde.re <- var(Y.test[-1, ]-Y.tilde2)
    
    return(list(Sigma = Sigma, Sigma.tilde = Sigma.tilde, Sigma.tilde.re = Sigma.tilde.re, 
                Sigma.perf = Sigma.perf, Pfull = Pfull, Pre = Pre))
}
